/* libfoXcontrol
 * Copyright (C) 2000 Josua Groeger
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/* FCComponent is the abstract base class for all foXcontrol components,
 * i.e. if you want to make a foXcontrol component you have to derive it
 * from FCComponent.
*/

#ifndef FCCOMPONENT_H
#define FCCOMPONENT_H

#include <fox/fx.h>

class FCComponent
{
  protected: // Variables you must/can initialize in create

    // Required
	FXComposite *composite; // The composite containing the buttons, textedits...

    // Recommended
    char section[50];     // The section i.e. the category of the component (e.g. "Desktop")
    char name[50];        // The component's name
    char description[100]; // A short description of the component

    FXIcon *icon;     // The component's icon
    FXIcon *miniIcon; // The component's mini icon

    // Optional
    bool noSettings; // True if the component does not provide user settings i.e. it just shows some information
    bool info;       // True if showInfo is implemented  
    bool help;       // True if showHelp is implemented

  public: // Public methods that do not matter to you if you want to make a component
    
    FCComponent ()
    {
      composite= NULL;
      strcpy (section, "(untitled)"); strcpy (name, "(untitled)"); description[0]= 0;
      noSettings= false; info= false; help= false;
      icon= NULL; miniIcon= NULL;
    };

    const char   *getSection     () {return section;};
    const char   *getName        () {return name;};
    const char   *getDescription () {return description;};

    const FXIcon *getIcon        () {return icon;};
    const FXIcon *getMiniIcon    () {return miniIcon;};

    bool          hasNoSettings  () {return noSettings;};
    bool          hasInfo        () {return info;};
    bool          hasHelp        () {return help;};
  
  public: // Virtual methods you must/can overwrite
  
    virtual ~FCComponent () {delete composite; delete icon; delete miniIcon;};
    
    virtual void create (FXComposite *p, FXuint opts= 0)= 0; // Initialize the protected variables
  
    virtual void readSettings       () {}; // Read the settings and change the buttons, textedits... of composite
    virtual void writeSettings      () {}; // Write the settings to the registry/configuration file...
    virtual void setDefaultSettings () {}; // Change the buttons, textedits... of composite so that they show the default settings

    virtual void showInfo           () {}; // Show an info box  
    virtual void showHelp           () {}; // Show the online help for the component
};

// You have to implement createFCComponent. Just write:
// _FCC $(your class derived from FCComponent) FCC_
#define _FCC extern "C" {FCComponent *createFCComponent () {return new
#define FCC_ ;}}
extern "C" {FCComponent *createFCComponent ();}

#endif