/* libfoXcontrol
 * Copyright (C) 2000 Josua Groeger
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "FCFrame.h"
#include <foXdesktop/foXdesktop.h>

// FXDEFMAP -------------------------------------------------------------------

FXDEFMAP (FCFrame) FCFrameMap[]=
{
  FXMAPFUNC (SEL_COMMAND, FXWindow::ID_SHOW     , FCFrame::onCmdShow),
  
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_INFO      , FCFrame::onInfo),
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_HELP      , FCFrame::onHelp),

  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_SETDEFAULT, FCFrame::onSetDefault),
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_RESET     , FCFrame::onReset),
  
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_OK        , FCFrame::onOK),
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_APPLY     , FCFrame::onApply),
  FXMAPFUNC (SEL_CLICKED, FCFrame::ID_CANCEL    , FCFrame::onCancel),
};

FXIMPLEMENT (FCFrame, FXVerticalFrame, FCFrameMap, ARRAYNUMBER (FCFrameMap));

// Constructor and destructor -------------------------------------------------

FCFrame::FCFrame (FXComposite *p, FXuint opts, FCComponent *cmp,
                  FXObject *apply_target= NULL, FXSelector apply_sel= 0, void *apply_ptr= NULL,
                  FXObject *hide_target= NULL, FXSelector hide_sel= 0, void *hide_ptr= NULL): FXVerticalFrame (p, opts)
{
  applySel= apply_sel;
  applyTarget= apply_target;
  applyPtr= apply_ptr;

  hideSel= hide_sel;
  hideTarget= hide_target;
  hidePtr= hide_ptr;

  captionFrame  = new FXHorizontalFrame (this, LAYOUT_FILL_X);
  infoFrame     = new FXPacker (captionFrame);
  nameFrame     = new FXPacker (captionFrame, LAYOUT_FILL_X|LAYOUT_FILL_Y);
  nameInnerFrame= new FXPacker (nameFrame, LAYOUT_CENTER_X|LAYOUT_CENTER_Y|FRAME_THICK);
  helpFrame     = new FXPacker (captionFrame);
  separator     = new FXHorizontalSeparator (this, FRAME_SUNKEN|LAYOUT_FILL_X);
  
  scrollWindow= new FXScrollWindow (this, LAYOUT_FILL_X|LAYOUT_FILL_Y);
  componentPacker= new FXPacker (scrollWindow, LAYOUT_FILL_X|LAYOUT_FILL_Y);
  component= cmp;
  component->create (componentPacker, LAYOUT_CENTER_X|LAYOUT_CENTER_Y);
  component->readSettings ();
  
  infoButton= new FXButton (infoFrame, "", (FXIcon*) component->getIcon (), this, ID_INFO, BUTTON_TOOLBAR|FRAME_RAISED);
  nameLabel = new FXLabel  (nameInnerFrame, component->getName ());
  helpButton= new FXButton (helpFrame, "", ((FXDApp*) getApp ())->insertIcon ("foXhelp.xpm"), this, ID_HELP, BUTTON_TOOLBAR|FRAME_RAISED);

  buttonFrame     = new FXHorizontalFrame (this, FRAME_SUNKEN|LAYOUT_FILL_X);
  leftButtonFrame = new FXHorizontalFrame (buttonFrame);
  rightButtonFrame= new FXHorizontalFrame (buttonFrame, LAYOUT_RIGHT);

  defaultButton= new FXButton (leftButtonFrame, "&Default", NULL, this, ID_SETDEFAULT);
  resetButton = new FXButton (leftButtonFrame, "&Reset" , NULL, this, ID_RESET);

  okButton     = new FXButton (rightButtonFrame  , "&OK"     , NULL, this, ID_OK);
  applyButton  = new FXButton (rightButtonFrame  , "&Apply"  , NULL, this, ID_APPLY);
  cancelButton = new FXButton (rightButtonFrame  , "&Cancel" , NULL, this, ID_CANCEL);

  if (component->hasNoSettings ())
  {
    defaultButton->hide ();
    resetButton->hide ();
    applyButton->hide ();
    cancelButton->hide ();
  }
  
  if (!component->hasInfo ()) infoButton->setFrameStyle (FRAME_NONE);
  if (!component->hasHelp ()) helpButton->hide ();
}

FCFrame::~FCFrame ()
{
  delete captionFrame;
  delete infoFrame;
  delete nameFrame;
  delete nameInnerFrame;
  delete helpFrame;
  delete separator;

  delete scrollWindow;
  delete componentPacker;
  delete component;

  delete infoButton;
  delete nameLabel;
  delete helpButton;

  delete buttonFrame;
  delete leftButtonFrame;
  delete rightButtonFrame;

  delete defaultButton;
  delete resetButton;

  delete okButton;
  delete applyButton;
  delete cancelButton;
}

// Public slots ---------------------------------------------------------------

long FCFrame::onCmdShow (FXObject* obj, FXSelector sel, void *ptr)
{
  component->readSettings ();
  return FXVerticalFrame::onCmdShow (obj, sel, ptr);
}

long FCFrame::onInfo (FXObject*, FXSelector, void*)
{
  component->showInfo ();
}

long FCFrame::onHelp (FXObject*, FXSelector, void*)
{
  component->showHelp ();
}

long FCFrame::onSetDefault (FXObject*, FXSelector, void*)
{
  component->setDefaultSettings ();
}

long FCFrame::onReset (FXObject*, FXSelector, void*)
{
  component->readSettings ();
}

long FCFrame::onOK (FXObject*, FXSelector, void*)
{
  component->writeSettings ();
  if (applyTarget) applyTarget->handle (this, applySel, applyPtr);
  if (hideTarget) hideTarget->handle (this, hideSel, hidePtr);
}

long FCFrame::onApply (FXObject*, FXSelector, void*)
{
  component->writeSettings ();
  if (applyTarget) applyTarget->handle (this, applySel, applyPtr);
}

long FCFrame::onCancel (FXObject*, FXSelector, void*)
{
  if (hideTarget) hideTarget->handle (this, hideSel, hidePtr); 
}