/* libfoXcontrol
 * Copyright (C) 2000 Josua Groeger
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/* FCFrame is a vertical frame containing a foXcontrol component('s composite) and
 * some buttons that invoke the proper methods of the component.
*/

#ifndef FCFRAME_H
#define FCFRAME_H

#include "FCComponent.h"

class FCFrame: public FXVerticalFrame
{
  FXDECLARE (FCFrame)
  protected:
	FCFrame () {};

    // Invoked by ok and apply
    FXObject *applyTarget;
    FXSelector applySel;
    void *applyPtr;

    // Invoked by ok and cancel
    FXObject *hideTarget;
    FXSelector hideSel;
    void *hidePtr;

    FXHorizontalFrame *captionFrame;
    FXPacker *infoFrame;
    FXPacker *nameFrame;
    FXPacker *nameInnerFrame;
    FXPacker *helpFrame;
    FXHorizontalSeparator *separator;

    FXScrollWindow *scrollWindow;
    FXPacker *componentPacker;
    FCComponent *component;

    FXButton *infoButton;
    FXLabel *nameLabel;
    FXButton *helpButton;

    FXHorizontalFrame *buttonFrame;
    FXHorizontalFrame *leftButtonFrame;
    FXHorizontalFrame *rightButtonFrame;

    FXButton *defaultButton;
    FXButton *resetButton;

    FXButton *okButton;
    FXButton *applyButton;
    FXButton *cancelButton;

  public:
	// cmp->create is invoked by the constructor
    FCFrame (FXComposite *p, FXuint opts, FCComponent *cmp,
             FXObject *apply_target= NULL, FXSelector apply_sel= 0, void *apply_ptr= NULL,
             FXObject *hide_target= NULL, FXSelector hide_sel= 0, void *hide_ptr= NULL);
    ~FCFrame ();
  
    FCComponent *getComponent () {return component;};

  public:
    enum
    {
      ID_INFO= FXMainWindow::ID_LAST,
      ID_HELP,
      ID_SETDEFAULT,
      ID_RESET,
      ID_OK,
      ID_APPLY,
      ID_CANCEL,
      ID_LAST
    };

    // public slots
    long onCmdShow (FXObject*, FXSelector, void*);

    long onInfo (FXObject*, FXSelector, void*);
    long onHelp (FXObject*, FXSelector, void*);

    long onSetDefault (FXObject*, FXSelector, void*);
    long onReset (FXObject*, FXSelector, void*);

    long onOK (FXObject*, FXSelector, void*);
    long onApply (FXObject*, FXSelector, void*);
    long onCancel (FXObject*, FXSelector, void*);
};

#endif